Documentation
¶
Index ¶
- Variables
- type ChromeOSProvision
- func (*ChromeOSProvision) Descriptor() ([]byte, []int)deprecated
- func (x *ChromeOSProvision) GetFileServer() string
- func (x *ChromeOSProvision) GetFinishedTime() *timestamppb.Timestamp
- func (x *ChromeOSProvision) GetHostname() string
- func (x *ChromeOSProvision) GetImage() string
- func (x *ChromeOSProvision) GetOriginalImage() string
- func (x *ChromeOSProvision) GetReason() string
- func (x *ChromeOSProvision) GetStartedTime() *timestamppb.Timestamp
- func (x *ChromeOSProvision) GetStatus() ChromeOSProvision_Status
- func (x *ChromeOSProvision) GetStep() []*ChromeOSProvision_Step
- func (x *ChromeOSProvision) GetTaskUrl() string
- func (*ChromeOSProvision) ProtoMessage()
- func (x *ChromeOSProvision) ProtoReflect() protoreflect.Message
- func (x *ChromeOSProvision) Reset()
- func (x *ChromeOSProvision) String() string
- type ChromeOSProvision_Status
- func (ChromeOSProvision_Status) Descriptor() protoreflect.EnumDescriptor
- func (x ChromeOSProvision_Status) Enum() *ChromeOSProvision_Status
- func (ChromeOSProvision_Status) EnumDescriptor() ([]byte, []int)deprecated
- func (x ChromeOSProvision_Status) Number() protoreflect.EnumNumber
- func (x ChromeOSProvision_Status) String() string
- func (ChromeOSProvision_Status) Type() protoreflect.EnumType
- type ChromeOSProvision_Step
- func (*ChromeOSProvision_Step) Descriptor() ([]byte, []int)deprecated
- func (x *ChromeOSProvision_Step) GetFinishedTime() *timestamppb.Timestamp
- func (x *ChromeOSProvision_Step) GetName() ChromeOSProvision_Step_Name
- func (x *ChromeOSProvision_Step) GetReason() string
- func (x *ChromeOSProvision_Step) GetStartedTime() *timestamppb.Timestamp
- func (x *ChromeOSProvision_Step) GetStatus() ChromeOSProvision_Status
- func (*ChromeOSProvision_Step) ProtoMessage()
- func (x *ChromeOSProvision_Step) ProtoReflect() protoreflect.Message
- func (x *ChromeOSProvision_Step) Reset()
- func (x *ChromeOSProvision_Step) String() string
- type ChromeOSProvision_Step_Name
- func (ChromeOSProvision_Step_Name) Descriptor() protoreflect.EnumDescriptor
- func (x ChromeOSProvision_Step_Name) Enum() *ChromeOSProvision_Step_Name
- func (ChromeOSProvision_Step_Name) EnumDescriptor() ([]byte, []int)deprecated
- func (x ChromeOSProvision_Step_Name) Number() protoreflect.EnumNumber
- func (x ChromeOSProvision_Step_Name) String() string
- func (ChromeOSProvision_Step_Name) Type() protoreflect.EnumType
- type DutState
- func (*DutState) Descriptor() ([]byte, []int)deprecated
- func (x *DutState) GetProvisionableAttributes() map[string]string
- func (x *DutState) GetProvisionableLabels() map[string]string
- func (*DutState) ProtoMessage()
- func (x *DutState) ProtoReflect() protoreflect.Message
- func (x *DutState) Reset()
- func (x *DutState) String() string
- type StableVersion
- func (*StableVersion) Descriptor() ([]byte, []int)deprecated
- func (x *StableVersion) GetFirmwareRoImagePath() string
- func (x *StableVersion) GetFirmwareRoVersion() string
- func (x *StableVersion) GetOsImagePath() string
- func (x *StableVersion) GetOsVersion() string
- func (x *StableVersion) GetTarget() *StableVersionTarget
- func (*StableVersion) ProtoMessage()
- func (x *StableVersion) ProtoReflect() protoreflect.Message
- func (x *StableVersion) Reset()
- func (x *StableVersion) String() string
- type StableVersionTarget
- func (*StableVersionTarget) Descriptor() ([]byte, []int)deprecated
- func (x *StableVersionTarget) GetBoard() string
- func (x *StableVersionTarget) GetDeviceType() string
- func (x *StableVersionTarget) GetModel() string
- func (x *StableVersionTarget) GetPool() string
- func (*StableVersionTarget) ProtoMessage()
- func (x *StableVersionTarget) ProtoReflect() protoreflect.Message
- func (x *StableVersionTarget) Reset()
- func (x *StableVersionTarget) String() string
- type StableVersions
Constants ¶
This section is empty.
Variables ¶
var ( ChromeOSProvision_Status_name = map[int32]string{ 0: "STATUS_UNKNOWN", 1: "STATUS_PASS", 2: "STATUS_FAIL", 3: "STATUS_ABORT", } ChromeOSProvision_Status_value = map[string]int32{ "STATUS_UNKNOWN": 0, "STATUS_PASS": 1, "STATUS_FAIL": 2, "STATUS_ABORT": 3, } )
Enum value maps for ChromeOSProvision_Status.
var ( ChromeOSProvision_Step_Name_name = map[int32]string{ 0: "NAME_UNDEFINED", 1: "NAME_PRE_PROVISION", 2: "NAME_ON_KERNEL", 3: "NAME_ON_ROOT_FS", 4: "NAME_ON_STATEFUL", 5: "NAME_POST_INST", 6: "NAME_POST_PROVISION", } ChromeOSProvision_Step_Name_value = map[string]int32{ "NAME_UNDEFINED": 0, "NAME_PRE_PROVISION": 1, "NAME_ON_KERNEL": 2, "NAME_ON_ROOT_FS": 3, "NAME_ON_STATEFUL": 4, "NAME_POST_INST": 5, "NAME_POST_PROVISION": 6, } )
Enum value maps for ChromeOSProvision_Step_Name.
var File_lab_platform_cros_provision_events_proto protoreflect.FileDescriptor
var File_lab_platform_dut_state_proto protoreflect.FileDescriptor
var File_lab_platform_stable_version_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type ChromeOSProvision ¶
type ChromeOSProvision struct {
// The URL of either AFE job or Swarming task.
TaskUrl string `protobuf:"bytes,1,opt,name=task_url,json=taskUrl,proto3" json:"task_url,omitempty"`
// The hostname of the DUT.
Hostname string `protobuf:"bytes,2,opt,name=hostname,proto3" json:"hostname,omitempty"`
// The image version to be provisioned, e.g. board-release/R12-34567.0.0.
Image string `protobuf:"bytes,3,opt,name=image,proto3" json:"image,omitempty"`
// The original image version before provisioning.
OriginalImage string `protobuf:"bytes,4,opt,name=original_image,json=originalImage,proto3" json:"original_image,omitempty"`
StartedTime *timestamppb.Timestamp `protobuf:"bytes,5,opt,name=started_time,json=startedTime,proto3" json:"started_time,omitempty"`
FinishedTime *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=finished_time,json=finishedTime,proto3" json:"finished_time,omitempty"`
// file_server describes the hostname:port of devserver/gs_cache server, e.g.
// 'chromeos6-devserver4:8888'.
FileServer string `protobuf:"bytes,7,opt,name=file_server,json=fileServer,proto3" json:"file_server,omitempty"`
Step []*ChromeOSProvision_Step `protobuf:"bytes,8,rep,name=step,proto3" json:"step,omitempty"`
Status ChromeOSProvision_Status `protobuf:"varint,9,opt,name=status,proto3,enum=lab_platform.ChromeOSProvision_Status" json:"status,omitempty"`
Reason string `protobuf:"bytes,10,opt,name=reason,proto3" json:"reason,omitempty"`
// contains filtered or unexported fields
}
ChromeOSProvision defines the provision events. It contains DUT and image information, as well as the details operations done on the DUT. Next Tag: 11
func (*ChromeOSProvision) Descriptor
deprecated
func (*ChromeOSProvision) Descriptor() ([]byte, []int)
Deprecated: Use ChromeOSProvision.ProtoReflect.Descriptor instead.
func (*ChromeOSProvision) GetFileServer ¶
func (x *ChromeOSProvision) GetFileServer() string
func (*ChromeOSProvision) GetFinishedTime ¶
func (x *ChromeOSProvision) GetFinishedTime() *timestamppb.Timestamp
func (*ChromeOSProvision) GetHostname ¶
func (x *ChromeOSProvision) GetHostname() string
func (*ChromeOSProvision) GetImage ¶
func (x *ChromeOSProvision) GetImage() string
func (*ChromeOSProvision) GetOriginalImage ¶
func (x *ChromeOSProvision) GetOriginalImage() string
func (*ChromeOSProvision) GetReason ¶
func (x *ChromeOSProvision) GetReason() string
func (*ChromeOSProvision) GetStartedTime ¶
func (x *ChromeOSProvision) GetStartedTime() *timestamppb.Timestamp
func (*ChromeOSProvision) GetStatus ¶
func (x *ChromeOSProvision) GetStatus() ChromeOSProvision_Status
func (*ChromeOSProvision) GetStep ¶
func (x *ChromeOSProvision) GetStep() []*ChromeOSProvision_Step
func (*ChromeOSProvision) GetTaskUrl ¶
func (x *ChromeOSProvision) GetTaskUrl() string
func (*ChromeOSProvision) ProtoMessage ¶
func (*ChromeOSProvision) ProtoMessage()
func (*ChromeOSProvision) ProtoReflect ¶
func (x *ChromeOSProvision) ProtoReflect() protoreflect.Message
func (*ChromeOSProvision) Reset ¶
func (x *ChromeOSProvision) Reset()
func (*ChromeOSProvision) String ¶
func (x *ChromeOSProvision) String() string
type ChromeOSProvision_Status ¶
type ChromeOSProvision_Status int32
Status defines the result for each step or the whole provision process to be reported.
const ( ChromeOSProvision_STATUS_UNKNOWN ChromeOSProvision_Status = 0 ChromeOSProvision_STATUS_PASS ChromeOSProvision_Status = 1 ChromeOSProvision_STATUS_FAIL ChromeOSProvision_Status = 2 ChromeOSProvision_STATUS_ABORT ChromeOSProvision_Status = 3 )
func (ChromeOSProvision_Status) Descriptor ¶
func (ChromeOSProvision_Status) Descriptor() protoreflect.EnumDescriptor
func (ChromeOSProvision_Status) Enum ¶
func (x ChromeOSProvision_Status) Enum() *ChromeOSProvision_Status
func (ChromeOSProvision_Status) EnumDescriptor
deprecated
func (ChromeOSProvision_Status) EnumDescriptor() ([]byte, []int)
Deprecated: Use ChromeOSProvision_Status.Descriptor instead.
func (ChromeOSProvision_Status) Number ¶
func (x ChromeOSProvision_Status) Number() protoreflect.EnumNumber
func (ChromeOSProvision_Status) String ¶
func (x ChromeOSProvision_Status) String() string
func (ChromeOSProvision_Status) Type ¶
func (ChromeOSProvision_Status) Type() protoreflect.EnumType
type ChromeOSProvision_Step ¶
type ChromeOSProvision_Step struct {
Name ChromeOSProvision_Step_Name `protobuf:"varint,1,opt,name=name,proto3,enum=lab_platform.ChromeOSProvision_Step_Name" json:"name,omitempty"`
StartedTime *timestamppb.Timestamp `protobuf:"bytes,2,opt,name=started_time,json=startedTime,proto3" json:"started_time,omitempty"`
FinishedTime *timestamppb.Timestamp `protobuf:"bytes,3,opt,name=finished_time,json=finishedTime,proto3" json:"finished_time,omitempty"`
Status ChromeOSProvision_Status `protobuf:"varint,4,opt,name=status,proto3,enum=lab_platform.ChromeOSProvision_Status" json:"status,omitempty"`
Reason string `protobuf:"bytes,5,opt,name=reason,proto3" json:"reason,omitempty"`
// contains filtered or unexported fields
}
Step defines the detail operations in a provision.
func (*ChromeOSProvision_Step) Descriptor
deprecated
func (*ChromeOSProvision_Step) Descriptor() ([]byte, []int)
Deprecated: Use ChromeOSProvision_Step.ProtoReflect.Descriptor instead.
func (*ChromeOSProvision_Step) GetFinishedTime ¶
func (x *ChromeOSProvision_Step) GetFinishedTime() *timestamppb.Timestamp
func (*ChromeOSProvision_Step) GetName ¶
func (x *ChromeOSProvision_Step) GetName() ChromeOSProvision_Step_Name
func (*ChromeOSProvision_Step) GetReason ¶
func (x *ChromeOSProvision_Step) GetReason() string
func (*ChromeOSProvision_Step) GetStartedTime ¶
func (x *ChromeOSProvision_Step) GetStartedTime() *timestamppb.Timestamp
func (*ChromeOSProvision_Step) GetStatus ¶
func (x *ChromeOSProvision_Step) GetStatus() ChromeOSProvision_Status
func (*ChromeOSProvision_Step) ProtoMessage ¶
func (*ChromeOSProvision_Step) ProtoMessage()
func (*ChromeOSProvision_Step) ProtoReflect ¶
func (x *ChromeOSProvision_Step) ProtoReflect() protoreflect.Message
func (*ChromeOSProvision_Step) Reset ¶
func (x *ChromeOSProvision_Step) Reset()
func (*ChromeOSProvision_Step) String ¶
func (x *ChromeOSProvision_Step) String() string
type ChromeOSProvision_Step_Name ¶
type ChromeOSProvision_Step_Name int32
const ( ChromeOSProvision_Step_NAME_UNDEFINED ChromeOSProvision_Step_Name = 0 ChromeOSProvision_Step_NAME_PRE_PROVISION ChromeOSProvision_Step_Name = 1 // Operations to prepare DUT before provision. ChromeOSProvision_Step_NAME_ON_KERNEL ChromeOSProvision_Step_Name = 2 // Write to kernel. ChromeOSProvision_Step_NAME_ON_ROOT_FS ChromeOSProvision_Step_Name = 3 // Write to root file system. ChromeOSProvision_Step_NAME_ON_STATEFUL ChromeOSProvision_Step_Name = 4 // Write to stateful partition. // Post-install process, e.g. update firmware, set next kernel, etc. ChromeOSProvision_Step_NAME_POST_INST ChromeOSProvision_Step_Name = 5 ChromeOSProvision_Step_NAME_POST_PROVISION ChromeOSProvision_Step_Name = 6 // Operations to verify if provision is good. )
func (ChromeOSProvision_Step_Name) Descriptor ¶
func (ChromeOSProvision_Step_Name) Descriptor() protoreflect.EnumDescriptor
func (ChromeOSProvision_Step_Name) Enum ¶
func (x ChromeOSProvision_Step_Name) Enum() *ChromeOSProvision_Step_Name
func (ChromeOSProvision_Step_Name) EnumDescriptor
deprecated
func (ChromeOSProvision_Step_Name) EnumDescriptor() ([]byte, []int)
Deprecated: Use ChromeOSProvision_Step_Name.Descriptor instead.
func (ChromeOSProvision_Step_Name) Number ¶
func (x ChromeOSProvision_Step_Name) Number() protoreflect.EnumNumber
func (ChromeOSProvision_Step_Name) String ¶
func (x ChromeOSProvision_Step_Name) String() string
func (ChromeOSProvision_Step_Name) Type ¶
func (ChromeOSProvision_Step_Name) Type() protoreflect.EnumType
type DutState ¶
type DutState struct {
// OS and/or fw versions installed on the DUT, e.g.
// {"cros-version":"terra-release/R75-12105.108.0"}.
// Used to construct variable bot dimensions.
ProvisionableLabels map[string]string `` /* 181-byte string literal not displayed */
// Variable DUT attributes, e.g.
// {"job_repo_url":"http://devserver_ip:8082/static/terra-release/R75-12105.108.0/autotest/packages"}.
// Are fed into the Autotest harness via the host info file.
ProvisionableAttributes map[string]string `` /* 189-byte string literal not displayed */
// contains filtered or unexported fields
}
DutState defines the structure of the file used to cache variable DUT information on the drone.
func (*DutState) Descriptor
deprecated
func (*DutState) GetProvisionableAttributes ¶
func (*DutState) GetProvisionableLabels ¶
func (*DutState) ProtoMessage ¶
func (*DutState) ProtoMessage()
func (*DutState) ProtoReflect ¶
func (x *DutState) ProtoReflect() protoreflect.Message
type StableVersion ¶
type StableVersion struct {
// The target description.
Target *StableVersionTarget `protobuf:"bytes,1,opt,name=target,proto3" json:"target,omitempty"`
// The version of the OS.
// e.g. "R80-14444.333.0"
OsVersion string `protobuf:"bytes,2,opt,name=os_version,json=osVersion,proto3" json:"os_version,omitempty"`
// The path of the OS image file.
// Examples:
// 1) "board-release/R80-14444.333.0"
// 2) "gs://bucket/board-release/R80-14444.333.0/file_name.tar.xz"
OsImagePath string `protobuf:"bytes,3,opt,name=os_image_path,json=osImagePath,proto3" json:"os_image_path,omitempty"`
// The version of the firmware RO.
// e.g. "Google_Board.14444.333.0"
FirmwareRoVersion string `protobuf:"bytes,4,opt,name=firmware_ro_version,json=firmwareRoVersion,proto3" json:"firmware_ro_version,omitempty"`
// The path of the firmware RO image file.
// Examples:
// 1) "board-firmware/R80-14444.333.0"
// 2) "gs://bucket/board-firmware/R80-14444.333.0/file_name.tar.xz"
FirmwareRoImagePath string `protobuf:"bytes,5,opt,name=firmware_ro_image_path,json=firmwareRoImagePath,proto3" json:"firmware_ro_image_path,omitempty"`
// contains filtered or unexported fields
}
StableVersion describe a single version record to decribe target device and vesrions need to be used for that.
func (*StableVersion) Descriptor
deprecated
func (*StableVersion) Descriptor() ([]byte, []int)
Deprecated: Use StableVersion.ProtoReflect.Descriptor instead.
func (*StableVersion) GetFirmwareRoImagePath ¶
func (x *StableVersion) GetFirmwareRoImagePath() string
func (*StableVersion) GetFirmwareRoVersion ¶
func (x *StableVersion) GetFirmwareRoVersion() string
func (*StableVersion) GetOsImagePath ¶
func (x *StableVersion) GetOsImagePath() string
func (*StableVersion) GetOsVersion ¶
func (x *StableVersion) GetOsVersion() string
func (*StableVersion) GetTarget ¶
func (x *StableVersion) GetTarget() *StableVersionTarget
func (*StableVersion) ProtoMessage ¶
func (*StableVersion) ProtoMessage()
func (*StableVersion) ProtoReflect ¶
func (x *StableVersion) ProtoReflect() protoreflect.Message
func (*StableVersion) Reset ¶
func (x *StableVersion) Reset()
func (*StableVersion) String ¶
func (x *StableVersion) String() string
type StableVersionTarget ¶
type StableVersionTarget struct {
// Device type like cros/android/tablet/labstation.
DeviceType string `protobuf:"bytes,1,opt,name=device_type,json=deviceType,proto3" json:"device_type,omitempty"`
// The board of the device.
// For CrOS it can be represented as build-target.
Board string `protobuf:"bytes,2,opt,name=board,proto3" json:"board,omitempty"`
// The model of the device.
Model string `protobuf:"bytes,3,opt,name=model,proto3" json:"model,omitempty"`
// The pool of the device.
Pool string `protobuf:"bytes,4,opt,name=pool,proto3" json:"pool,omitempty"`
// contains filtered or unexported fields
}
StableVersionTarget describes details of target devices.
func (*StableVersionTarget) Descriptor
deprecated
func (*StableVersionTarget) Descriptor() ([]byte, []int)
Deprecated: Use StableVersionTarget.ProtoReflect.Descriptor instead.
func (*StableVersionTarget) GetBoard ¶
func (x *StableVersionTarget) GetBoard() string
func (*StableVersionTarget) GetDeviceType ¶
func (x *StableVersionTarget) GetDeviceType() string
func (*StableVersionTarget) GetModel ¶
func (x *StableVersionTarget) GetModel() string
func (*StableVersionTarget) GetPool ¶
func (x *StableVersionTarget) GetPool() string
func (*StableVersionTarget) ProtoMessage ¶
func (*StableVersionTarget) ProtoMessage()
func (*StableVersionTarget) ProtoReflect ¶
func (x *StableVersionTarget) ProtoReflect() protoreflect.Message
func (*StableVersionTarget) Reset ¶
func (x *StableVersionTarget) Reset()
func (*StableVersionTarget) String ¶
func (x *StableVersionTarget) String() string
type StableVersions ¶
type StableVersions struct {
Versions []*StableVersion `protobuf:"bytes,4,rep,name=versions,proto3" json:"versions,omitempty"`
// contains filtered or unexported fields
}
StableVersions is a structure containing all of the versions for various components: OS anf firmware details. Next Tag: 5
func (*StableVersions) Descriptor
deprecated
func (*StableVersions) Descriptor() ([]byte, []int)
Deprecated: Use StableVersions.ProtoReflect.Descriptor instead.
func (*StableVersions) GetVersions ¶
func (x *StableVersions) GetVersions() []*StableVersion
func (*StableVersions) ProtoMessage ¶
func (*StableVersions) ProtoMessage()
func (*StableVersions) ProtoReflect ¶
func (x *StableVersions) ProtoReflect() protoreflect.Message
func (*StableVersions) Reset ¶
func (x *StableVersions) Reset()
func (*StableVersions) String ¶
func (x *StableVersions) String() string